as.data.frame.ddsimcares: Creates a data frame from DD-SIMCA classification results.

View source: R/ddsimcares.R

as.data.frame.ddsimcaresR Documentation

Creates a data frame from DD-SIMCA classification results.

Description

The data frame contains object label, class label (if provided), role, decision, as well as values for distances (h/h0, q/q0, f) for every object from dataset used to create the results object.

Usage

## S3 method for class 'ddsimcares'
as.data.frame(
  x,
  row.names = NULL,
  optional = FALSE,
  ...,
  ncomp = x$ncomp.selected,
  limType = "classic"
)

Arguments

x

classification results (object of class ddsimcares).

row.names

NULL or a character vector giving the row names for the data frame (not used).

optional

logical, if TRUE, setting row names is optional (not used).

...

other arguments

ncomp

model complexity (number of components) to compute the classification results for.

limType

limit type to use ('classic' or 'robust')

Value

a data frame.


mdatools documentation built on March 6, 2026, 5:08 p.m.