as.matrix.ddsimcares: Creates a matrix from DD-SIMCA classification results.

View source: R/ddsimcares.R

as.matrix.ddsimcaresR Documentation

Creates a matrix from DD-SIMCA classification results.

Description

The matrix contains results characteristics computed for different number of components, including number of objects accepted/rejected by the model, explained and cumulative explained variance, as well as (if reference classes are provided) main figures of merits (TP, FP, TN, FN, sensitivity, specificity, efficiency and selectivity).

If dataset used to create the results contained only target class members or only objects from alternative classes, the FoMs will be reduced accordingly.

Usage

## S3 method for class 'ddsimcares'
as.matrix(x, limType = "classic", ...)

Arguments

x

classification results (object of class ddsimcares).

limType

limit type to use ('classic' or 'robust')

...

other arguments

Value

a matrix.


mdatools documentation built on March 6, 2026, 5:08 p.m.