as.matrix.plsdares: as.matrix method for PLS-DA results
Description
Returns a matrix with model performance statistics for PLS-DA results
Usage
# S3 method for plsdares
as.matrix(x, ncomp = NULL, nc = 1, ...)
Arguments
x
PLS-DA results (object of class plsdares)
ncomp
number of components to calculate the statistics for (if NULL gets for all components)
nc
for which class to calculate the statistics for