clamp.dof: Round and clamp degrees of freedom to valid range [1, 250]

View source: R/ldecomp.R

clamp.dofR Documentation

Round and clamp degrees of freedom to valid range [1, 250]

Description

Round and clamp degrees of freedom to valid range [1, 250]

Usage

clamp.dof(x)

Arguments

x

vector with raw degrees of freedom values

Value

vector with rounded and clamped values


mdatools documentation built on March 6, 2026, 5:08 p.m.