classify: Creates classification outcomes for given PCA result objects...

View source: R/ddsimca.R

classifyR Documentation

Creates classification outcomes for given PCA result objects and distance parameters.

Description

Creates classification outcomes for given PCA result objects and distance parameters.

Usage

classify(
  pcares,
  indices,
  numbers,
  qp,
  hp,
  nobj.cal,
  alpha = 0.05,
  gamma = 0.01,
  classname,
  c.ref = NULL
)

Arguments

pcares

object of class pcares.

indices

list with indices of members, strangers, and unknown samples as well as information about excluded objects.

numbers

list with numbers of members, strangers, unknown and excluded samples.

qp

distribution parameters for q-distances.

hp

distribution parameters for h-distances.

nobj.cal

number of objects in calibration set the model was built on (needed for outliers detection).

alpha

significance level for decision boundary.

gamma

significance level for outlier detection boundary,

classname

name of the target class.

c.ref

vector with names of the reference classes.

Value

a list with classification outcomes for each number of components.


mdatools documentation built on March 6, 2026, 5:08 p.m.