cleanLabels: Clean text labels from extra elements so they are compatible...

View source: R/misc.R

cleanLabelsR Documentation

Clean text labels from extra elements so they are compatible with JSON

Description

Clean text labels from extra elements so they are compatible with JSON

Usage

cleanLabels(str)

Arguments

str

label string (for example produced by expression).


mdatools documentation built on March 6, 2026, 5:08 p.m.