constraintClosure: Method for closure constraint

View source: R/constraints.R

constraintClosureR Documentation

Method for closure constraint

Description

Force rows of data sum up to given value

Usage

constraintClosure(x, d, sum = 1)

Arguments

x

data matrix (spectra or contributions)

d

matrix with the original spectral values

sum

which value the spectra or contributions should sum up to


mdatools documentation built on March 6, 2026, 5:08 p.m.