getConvexHull: Compute coordinates of a closed convex hull for data points

View source: R/plotseries.R

getConvexHullR Documentation

Compute coordinates of a closed convex hull for data points

Description

Compute coordinates of a closed convex hull for data points

Usage

getConvexHull(points)

Arguments

points

matrix or data frame with coordinates of the points


mdatools documentation built on March 6, 2026, 5:08 p.m.