getMainTitle: Get main title

View source: R/misc.R

getMainTitleR Documentation

Get main title

Description

returns main title for a plot depending on a user choice

Usage

getMainTitle(main, ncomp, default)

Arguments

main

main title of a plot, provided by user

ncomp

number of components to select, provided by user

default

default title for the plot

Details

Depending on a user choice it returns main title for a plot


mdatools documentation built on March 6, 2026, 5:08 p.m.