getProbabilities.simca: Probabilities of class belonging for PCA/SIMCA results

View source: R/simca.R

getProbabilities.simcaR Documentation

Probabilities of class belonging for PCA/SIMCA results

Description

Probabilities of class belonging for PCA/SIMCA results

Usage

## S3 method for class 'simca'
getProbabilities(obj, ncomp, q, h, ...)

Arguments

obj

object with PCA model

ncomp

number of components to compute the probability for

q

vector with squared orthogonal distances for given number of components

h

vector with score distances for given number of components

...

other parameters

Details

Computes p-value for every object being from the same population as calibration set based on its orthogonal and score distances.


mdatools documentation built on March 6, 2026, 5:08 p.m.