getPureVariables: Identifies pure variables

View source: R/mcrpure.R

getPureVariablesR Documentation

Identifies pure variables

Description

The method identifies indices of pure variables using the SIMPLISMA algorithm.

Usage

getPureVariables(D, ncomp, purevars, offset)

Arguments

D

matrix with the spectra

ncomp

number of pure components

purevars

user provided values for pure variables (no calculation will be run in this case)

offset

offset (between 0 and 1) for calculation of parameter alpha

Value

The function returns a list with the following fields:

ncomp

number of pure components.

purevars

vector with indices for pure variables.

purityspec

matrix with purity values for each resolved components.

purevals

vector with purity values for resolved components.


mdatools documentation built on March 6, 2026, 5:08 p.m.