getSelectedComponents: Get selected components

View source: R/misc.R

getSelectedComponentsR Documentation

Get selected components

Description

returns number of components depending on a user choice

Usage

getSelectedComponents(obj, ncomp = NULL)

Arguments

obj

an MDA model or result object (e.g. pca, pls, simca, etc)

ncomp

number of components to select, provided by user

Details

Depending on a user choice it returns optimal number of component for the model (if user did not provide any value) or check the user choice for correctness and returns it back


mdatools documentation built on March 6, 2026, 5:08 p.m.