| ldecomp.getLimParams | R Documentation |
Compute parameters for critical limits based on calibration results
ldecomp.getLimParams(U, do.round = TRUE)
U |
matrix with residual distances |
do.round |
logical, shall Nu values be rounded or not |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.