| ldecomp.plotResiduals | R Documentation |
ldecomp.plotDistances instead).Shows a plot with score (T2, h) vs orthogonal (Q, q) distances and corresponding critical limits for given number of components.
ldecomp.plotResiduals(res, ...)
res |
list with result objects to show the plot for |
... |
other parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.