Calculates limits for y-axis depending on data values that have to be plotted, extra plot elements that have to be shown and margins.
mdaplot.getYAxisLim(
ps,
ylim,
show.lines = FALSE,
show.excluded = FALSE,
show.labels = FALSE,
show.colorbar = FALSE
)`plotseries` object.
limits provided by user
logical or numeric with line coordinates to be shown on the plot.
logical, will excluded values be shown on the plot
logical, will data labels be shown on the plot
logical, will colorbar be shown on the plot
Returns a vector with two limits.