Prepare data for mdaplotg
mdaplotg.prepareData(data, type, groupby)datasets (in form of list, matrix or data frame)
vector with type for dataset
factor or data frame with factors - used to split data matrix into groups
list of datasets
The method should prepare data as a list of datasets (matrices or data frames). One list element will be used to create one plot series.
If `data` is matrix or data frame and not `groupby` parameter is provided, then every row will be taken as separate set. This option is available only for line or bar plots.