mdaplotyy create line plot for two plot series and uses separate y-axis for each.
mdaplotyy(
data,
type = "l",
col = mdaplot.getColors(2),
lty = c(1, 1),
lwd = c(1, 1),
pch = (if (type == "b") c(16, 16) else c(NA, NA)),
cex = 1,
xlim = NULL,
ylim = NULL,
main = attr(data, "name"),
xlab = attr(data, "xaxis.name"),
ylab = rownames(data),
labels = "values",
show.labels = FALSE,
lab.cex = 0.65,
lab.col = "darkgray",
show.grid = TRUE,
grid.lwd = 0.5,
grid.col = "lightgray",
xticks = NULL,
xticklabels = NULL,
xlas = 0,
ylas = 0,
show.legend = TRUE,
legend.position = "topright",
legend = ylab,
...
)a matrix or a data.frame with two rows of values.
type of the plot ("l" or "b").
a color for markers or lines (same as plot parameter) for each series.
line type for each series (two values)
line width for each series (two values)
a character for markers (same as plot parameter) for each series (two values).
scale factor for the markers
limits for the x axis (if NULL, will be calculated automatically).
limits for the y axis, either list with two vectors (one for each series) or NULL.
an overall title for the plot (same as plot parameter).
a title for the x axis (same as plot parameter).
a title for each of the two y axis (as a vector of two text values).
a vector with text labels for data points or one of the following: "names", "indices", "values".
logical, show or not labels for the data objects.
size for data point labels.
color for data point labels.
logical, show or not a grid for the plot.
line thinckness (width) for the grid.
line color for the grid.
values for x ticks.
labels for x ticks.
orientation of xticklabels.
orientation of yticklabels (will be applied to both y axes).
logical show legend with name of each plot series or not
position of legend if it must be shown
values for the legend
other plotting arguments.
This plot has properties both mdaplot and mdaplotg, so when you specify color,
line properties etc. you have to do it for both plot series.
mdaplotg - to make plots for several sets of data objects (groups of objects).
# NOT RUN {
# See all examples in the tutorial.
# }
Run the code above in your browser using DataLab