| plotExtremes.ddsimca | R Documentation |
Shows a plot with number of expected vs. number of observed extreme objects for different significance levels (alpha values) for calibration and PV-set results.
## S3 method for class 'ddsimca'
plotExtremes(
obj,
ncomp = obj$ncomp.selected,
limType = "classic",
col = mdaplot.getColors(2),
pch = c(16, 16),
legend.position = "topleft",
...
)
obj |
a DD-SIMCA model (object of class |
ncomp |
number of components to show the plot for |
limType |
limit type to show the plot for ('classic' or 'robust'). |
col |
vector with two colors (for calibration and PV-set sensitivity). |
pch |
vector with two markers (for calibration and PV-set sensitivity). |
legend.position |
position of the legend |
... |
other arguments, suitable for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.