plotExtremes.ddsimcares: Extremes plot.

View source: R/ddsimcares.R

plotExtremes.ddsimcaresR Documentation

Extremes plot.

Description

The method generates a sequence of values for significance level (alpha) and then computes how many extremes the model produces by applying it to the target class members. After that the computed number is plotted against the expected number.

The plot also shows a confidence ellipse for the expected values.

Usage

## S3 method for class 'ddsimcares'
plotExtremes(
  obj,
  ncomp = obj$ncomp.selected,
  limType = "classic",
  main = sprintf("Extremes (A = %d)", ncomp),
  xlab = "Number of extremes (expected)",
  ylab = "Number of extremes (observed)",
  col = "#2679b2",
  pch = 16,
  ellipse.col = "#eeeeee",
  show.plot = TRUE,
  ...
)

Arguments

obj

DD-SIMCA results (object of class ddsimcares)

ncomp

number of components in the model to show the plot for.

limType

limit type to show the plot for ('classic' or 'robust').

main

main title.

xlab

label for x-axis.

ylab

label for y-axis.

col

color of the plot points.

pch

color of the plot points.

ellipse.col

color of the confidence ellipse elements.

show.plot

logical, if FALSE returns only values and does not show the plot.

...

other parameters compatible with mdaplot method.


mdatools documentation built on March 6, 2026, 5:08 p.m.