plotFoM.ddsimcares: Figure of merit plot.

View source: R/ddsimcares.R

plotFoM.ddsimcaresR Documentation

Figure of merit plot.

Description

Figure of merit plot.

Usage

## S3 method for class 'ddsimcares'
plotFoM(
  obj,
  fom = "sens",
  limType = "classic",
  type = "b",
  ylim = c(0, 1.1),
  show.plot = TRUE,
  ...
)

Arguments

obj

DD-SIMCA results (object of class ddsimcares)

fom

name of the figure of merit to show the plot for ('sens', 'spec', 'sel', 'eff', 'acc').

limType

limit type to show the plot for ('classic' or 'robust').

type

type of plot (can be 'b', 'l', or 'h').

ylim

limits for y-axis.

show.plot

logical, if FALSE returns only values and does not show the plot.

...

any parameters for mdaplot method can be provided.

Shows the selected figure of merit values vs. number of components. Pay attention, that some of the FoMs may not be available, for example if result object is made only for members of the target class, only sensitivity ('sens') is available.


mdatools documentation built on March 6, 2026, 5:08 p.m.