plotLoadings.pca: Loadings plot for PCA model

View source: R/pca.R

plotLoadings.pcaR Documentation

Loadings plot for PCA model

Description

Shows a loadings plot for selected components.

Usage

## S3 method for class 'pca'
plotLoadings(
  obj,
  comp = if (obj$ncomp > 1) c(1, 2) else 1,
  type = (if (length(comp) == 2) "p" else "l"),
  show.legend = TRUE,
  show.axes = TRUE,
  ...
)

Arguments

obj

a PCA model (object of class pca)

comp

a value or vector with several values - number of components to show the plot for

type

type of the plot ('b', 'l', 'h')

show.legend

logical, show or not a legend on the plot

show.axes

logical, show or not axes lines crossing origin (0,0)

...

other plot parameters (see mdaplotg for details)

Details

See examples in help for pca function.


mdatools documentation built on March 6, 2026, 5:08 p.m.