plotSelection.ipls: iPLS performance plot

View source: R/ipls.R

plotSelection.iplsR Documentation

iPLS performance plot

Description

Shows PLS performance for each selected or excluded intervals at the first iteration.

Usage

## S3 method for class 'ipls'
plotSelection(
  obj,
  glob.ncomp = obj$gm$ncomp.selected,
  main = "iPLS results",
  xlab = obj$xaxis.name,
  ylab = if (is.null(obj$cv)) "RMSEP" else "RMSECV",
  xlim = NULL,
  ylim = NULL,
  ...
)

Arguments

obj

iPLS results (object of class ipls).

glob.ncomp

number of components for global PLS model with all intervals.

main

main title for the plot.

xlab

label for x-axis.

ylab

label for y-axis.

xlim

limits for x-axis.

ylim

limits for y-axis.

...

other arguments.

Details

The plot shows intervals as bars, which height corresponds to RMSECV obtained when particular interval was selected (forward) or excluded (backward) from a model at the first iteration. The intervals found optimal after backward/forward iPLS selection are shown with green color while the other intervals are gray.

See examples in help for ipls function.

See Also

summary.ipls, plotRMSE.ipls


mdatools documentation built on March 6, 2026, 5:08 p.m.