plotSelectivityArea.ddsimcares: Selectivity area plot (similar to ROC curve).

View source: R/ddsimcares.R

plotSelectivityArea.ddsimcaresR Documentation

Selectivity area plot (similar to ROC curve).

Description

The method generates a sequence of values for significance level (alpha) and then computes corresponding selectivity (1 - beta) for each value from the sequence using model parameters for given number of components and limit type. Then the values are shown as line plot using coordinates (1 - alpha) vs beta and area under the curve is shown in the plot title.

Current values of alpha and beta are shown on the plot as a marker.

Usage

## S3 method for class 'ddsimcares'
plotSelectivityArea(
  obj,
  ncomp = obj$ncomp.selected,
  limType = "classic",
  col = "#2679b2",
  xlab = bquote("1 - selectivity, " ~ beta),
  ylab = bquote("Sensitivity, 1 - " ~ alpha),
  ...
)

Arguments

obj

DD-SIMCA results (object of class ddsimcares).

ncomp

number of components in the model to show the plot for.

limType

limit type to show the plot for ('classic' or 'robust').

col

color of the plot elements.

xlab

label for x-axis.

ylab

label for y-axis.

...

other parameters compatible with mdaplot method.


mdatools documentation built on March 6, 2026, 5:08 p.m.