plotSensitivity.ddsimcares: Sensitivity plot.

View source: R/ddsimcares.R

plotSensitivity.ddsimcaresR Documentation

Sensitivity plot.

Description

Sensitivity plot.

Usage

## S3 method for class 'ddsimcares'
plotSensitivity(
  obj,
  show.ci = FALSE,
  ci.col = "#a0a0a0",
  ci.lty = c(3, 2, 3),
  ...
)

Arguments

obj

DD-SIMCA results (object of class ddsimcares).

show.ci

logical, show or not the expected sensitivity and 95% confidence interval for it.

ci.col

color for lines showing expected sensitivity and confidence interval.

ci.lty

type of lines (lower, expected, upper) for the expected sensitivity and confidence interval.

...

any parameters suitable for the plotFoM.ddsimcares method.

Details

The method is a wrapper for more general plotFoM.ddsimcares method with a possibility to show confidence interval for the expected sensitivity.


mdatools documentation built on March 6, 2026, 5:08 p.m.