plotXYLoadings.pls: XY loadings plot for PLS

View source: R/pls.R

plotXYLoadings.plsR Documentation

XY loadings plot for PLS

Description

Shows plot with X and Y loading values for selected components.

Usage

## S3 method for class 'pls'
plotXYLoadings(obj, comp = c(1, 2), show.axes = TRUE, ...)

Arguments

obj

a PLS model (object of class pls)

comp

which components to show the plot for (one or vector with several values)

show.axes

logical, show or not axes lines crossing origin (0,0)

...

other plot parameters (see mdaplotg for details)

Details

See examples in help for pls function.


mdatools documentation built on March 6, 2026, 5:08 p.m.