| pls.getyscores | R Documentation |
Compute and orthogonalize matrix with Y-scores
pls.getyscores(y, yloadings, xscores, exclrows)
y |
matrix with response values, already preprocessed and cleaned |
yloadings |
matrix with Y-loadings |
xscores |
matrix with X-scores (needed for orthogonalization) |
exclrows |
vector with indices of excluded rows if any |
matrix with Y-scores
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.