prep.apply: Applies a list with preprocessing methods to a dataset

View source: R/prep.R

prep.applyR Documentation

Applies a list with preprocessing methods to a dataset

Description

Applies a list with preprocessing methods to a dataset

Usage

prep.apply(obj, x)

Arguments

obj

list with preprocessing methods (created using prep or prep.fit function).

x

matrix with dataset


mdatools documentation built on March 6, 2026, 5:08 p.m.