prep.emsc: Applies Extended Multiplicative Scatter Correction to data...

View source: R/prep.R

prep.emscR Documentation

Applies Extended Multiplicative Scatter Correction to data rows

Description

Applies Extended Multiplicative Scatter Correction to data rows

Usage

prep.emsc(data, degree = 0, mspectrum = NULL, lnorm = NULL, A = NULL)

Arguments

data

a matrix with data values.

degree

polynomial degree, if 0 then the result will be the same as for conventional MSC.

mspectrum

optional reference spectrum (if not provided, mean spectrum will be used).

lnorm

do not use, required for training of preprocessing model.

A

do not use, required for training of preprocessing model.


mdatools documentation built on March 6, 2026, 5:08 p.m.