prep.fit: Fits preprocessing model

View source: R/prep.R

prep.fitR Documentation

Fits preprocessing model

Description

Fits preprocessing model

Usage

prep.fit(obj, x)

Arguments

obj

list with preprocessing methods (created using prep or prep.fit function).

x

matrix with training set to be used for computing data dependent parameters

Value

same list but with updated methods parameters computed based on the training set.


mdatools documentation built on March 6, 2026, 5:08 p.m.