preparePlotData: Take dataset and prepare them for plot

View source: R/plotseries.R

preparePlotDataR Documentation

Take dataset and prepare them for plot

Description

The function checks that 'data' contains correct numeric values, checks for mandatory attributes (row and column names, x- and y-axis values and names, etc.) and adds them if necessary.

Another thing is to remove hidden columns and split the rest to visible and hidden values (if excluded rows are present).

Usage

preparePlotData(data)

Arguments

data

dataset (vector, matrix or data frame)


mdatools documentation built on March 6, 2026, 5:08 p.m.