print.prepmodel: Print the information about methods in the preprocessing...

View source: R/prep.R

print.prepmodelR Documentation

Print the information about methods in the preprocessing model.

Description

Print the information about methods in the preprocessing model.

Usage

## S3 method for class 'prepmodel'
print(x, ...)

Arguments

x

preprocessing model (created by prep.fit).

...

potential further arguments (required for Method/Generic reasons).

Value

the x argument (invisibly).


mdatools documentation built on March 6, 2026, 5:08 p.m.