print.regcoeffs: print method for regression coefficients class
Description
prints regression coeffocoent values for given response number and amount of components
Usage
"print"(x, ncomp = 1, ny = 1, digits = 3, ...)
Arguments
x
regression coefficients object (class regcoeffs)
ncomp
number of components to return the coefficients for
ny
number of response variable to return the coefficients for
digits
decimal digits round the coefficients to