| processMembers | R Documentation |
Computes classification outcomes for target class members.
processMembers(res, indMembers)
res |
a list with classification outcomes created by method |
indMembers |
a vector with logical values pointing on data items corresponding to class members. |
the res list where roles vector is filled for class members, plus values for TP and FN.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.