processStrangers: Computes classification outcomes for members of non-target...

View source: R/ddsimca.R

processStrangersR Documentation

Computes classification outcomes for members of non-target classes.

Description

Computes classification outcomes for members of non-target classes.

Usage

processStrangers(res, indStrangers)

Arguments

res

a list with classification outcomes created by method classify (part of it will be filled by this method).

indStrangers

a vector with logical values pointing on data items corresponding to members of non-target classes.

Value

the res list where roles vector is filled for class members, values for TN and FP, as well as statistics for computing Type II error and related things (beta, s, f0, hz, Mz, Sz, k, m).


mdatools documentation built on March 6, 2026, 5:08 p.m.