Learn R Programming

mdatools (version 0.13.1)

rotationMatrixToX1: Creates a rotation matrix to map a vector x to [1 0 0 ... 0]

Description

Creates a rotation matrix to map a vector x to [1 0 0 ... 0]

Usage

rotationMatrixToX1(x)

Value

Rotation matrix (JxJ)

Arguments

x

Vector (sequence with J coordinates)