selratio: Selectivity ratio calculation

View source: R/pls.R

selratioR Documentation

Selectivity ratio calculation

Description

Calculates selectivity ratio for all response variables in the PLS model with given number of components.

Usage

selratio(obj, ncomp = obj$ncomp.selected)

Arguments

obj

a PLS model (object of class pls)

ncomp

number of components to use in the model for calculation.

Value

array nvar x ny with selectivity ratio values

References

[1] Tarja Rajalahti et al. Chemometrics and Laboratory Systems, 95 (2009), pp. 35-48.


mdatools documentation built on March 6, 2026, 5:08 p.m.