writeCSV: Method to write outcomes of any result object to CSV file

View source: R/defaults.R

writeCSVR Documentation

Method to write outcomes of any result object to CSV file

Description

Method to write outcomes of any result object to CSV file

Usage

writeCSV(res, fileName, name, sep = ",", dataFile = "", ...)

Arguments

res

result object (plsres, pcares, etc.).

fileName

name (or full path) to CSV file to be created.

name

short name of the result object (e.g. "cal", "test". etc.).

sep

values separator (either "," or ";").

dataFile

optional, name of the data file used to create the results.

...

other optional parameters


mdatools documentation built on March 6, 2026, 5:08 p.m.