writeCSV.ddsimcares: Save DD-SIMCA results to CSV file

View source: R/ddsimcares.R

writeCSV.ddsimcaresR Documentation

Save DD-SIMCA results to CSV file

Description

Saves DD-SIMCA results to CSV file with structure identical to the one generated by web-application at https://mda.tools/ddsimca

Usage

## S3 method for class 'ddsimcares'
writeCSV(
  res,
  fileName,
  name = "cal",
  sep = ",",
  dataFile = "",
  ncomp = res$ncomp.selected,
  limType = "classic",
  src = "mdatools for R",
  ...
)

Arguments

res

DD-SIMCA results (object of class ddsimcares)

fileName

name (or full path) to CSV file to be created.

name

short name of the result object (e.g. "cal", "test". etc.).

sep

values separator (either "," or ";").

dataFile

optional, name of the data file used to create the results.

ncomp

model complexity (number of components) to compute the classiciation results for.

limType

limit type to use ('classic' or 'robust')

src

optional, source of the results

...

other optional parameters


mdatools documentation built on March 6, 2026, 5:08 p.m.