writeCSV.pcares: Save PCA results to CSV file

View source: R/pcares.R

writeCSV.pcaresR Documentation

Save PCA results to CSV file

Description

Saves PCA results to CSV file with structure identical to the one generated by web-application at https://mda.tools/pca

Usage

## S3 method for class 'pcares'
writeCSV(
  res,
  fileName,
  name,
  sep = ",",
  dataFile = "",
  classes = NULL,
  model = NULL,
  ...
)

Arguments

res

PCA results (object of class pcares)

fileName

name (or full path) to CSV file to be created.

name

short name of the result object (e.g. "cal", "test". etc.).

sep

values separator (either "," or ";").

dataFile

optional, name of the data file used to create the results.

classes

vector with class names for every object in the dataset (if any)

model

optional, if PCA model is provided, loadings and vectors for centering/scaling will be added

...

other optional parameters


mdatools documentation built on March 6, 2026, 5:08 p.m.