writeCSV.plsres: Save PLS results to CSV file

View source: R/plsres.R

writeCSV.plsresR Documentation

Save PLS results to CSV file

Description

Saves PLS results to CSV file with structure identical to the one generated by web-application at https://mda.tools/pls

Usage

## S3 method for class 'plsres'
writeCSV(res, fileName, name, sep = ",", dataFile = "", ...)

Arguments

res

PLS results (object of class plsres)

fileName

name (or full path) to CSV file to be created.

name

short name of the result object (e.g. "cal", "test". etc.).

sep

values separator (either "," or ";").

dataFile

optional, name of the data file used to create the results.

...

other optional parameters


mdatools documentation built on March 6, 2026, 5:08 p.m.