| as.data.frame.ddsimcares | R Documentation |
The data frame contains object label, class label (if provided), role, decision, as well as values for distances (h/h0, q/q0, f) for every object from dataset used to create the results object.
## S3 method for class 'ddsimcares'
as.data.frame(
x,
row.names = NULL,
optional = FALSE,
...,
ncomp = x$ncomp.selected,
limType = "classic"
)
x |
classification results (object of class |
row.names |
NULL or a character vector giving the row names for the data frame (not used). |
optional |
logical, if TRUE, setting row names is optional (not used). |
... |
other arguments |
ncomp |
model complexity (number of components) to compute the classification results for. |
limType |
limit type to use ('classic' or 'robust') |
a data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.