| as.matrix.ddsimcares | R Documentation |
The matrix contains results characteristics computed for different number of components, including number of objects accepted/rejected by the model, explained and cumulative explained variance, as well as (if reference classes are provided) main figures of merits (TP, FP, TN, FN, sensitivity, specificity, efficiency and selectivity).
If dataset used to create the results contained only target class members or only objects from alternative classes, the FoMs will be reduced accordingly.
## S3 method for class 'ddsimcares'
as.matrix(x, limType = "classic", ...)
x |
classification results (object of class |
limType |
limit type to use ('classic' or 'robust') |
... |
other arguments |
a matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.