constraintClosure: Method for closure constraint
Description
Force rows of data sum up to given value
Usage
constraintClosure(x, d, sum = 1)
Arguments
x
data matrix (spectra or contributions)
d
matrix with the original spectral values
sum
which value the specra or contributions should sum up to