The method identifies indices of pure variables using the SIMPLISMA algorithm.
getPureVariables(D, ncomp, purevars, offset)matrix with the spectra
number of pure components
user provided values gor pure variables (no calculation will be run in this case)
offset (between 0 and 1) for calculation of parameter alpha
The function returns a list with with following fields:
number of pure components.
vector with indices for pure variables.
matrix with purity values for each resolved components.
vector with purity values for resolved components.