| mda.subset | R Documentation |
A wrapper for subset() method with proper set of attributes
mda.subset(x, subset = NULL, select = NULL)
x |
dataset (data frame or matrix) |
subset |
which rows to keep (indices, names or logical values) |
select |
which columns to select (indices, names or logical values) |
The method works similar to the standard subset() method, with minor differences. First
of all it keeps (and corrects, if necessary) all important attributes. If only columns are
selected, it keeps all excluded rows as excluded. If only rows are selected, it keeps all
excluded columns. If both rows and columns are selected it removes all excluded elements first
and then makes the subset.
The parameters subset and select may each be a vector with numbers or names
without excluded elements, or a logical expression.
a data with the subset
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.