| plotAcceptance.ddsimcares | R Documentation |
Shows a plot with h/h0 and q/q0 distance values for given number of components and type of critical limits.
## S3 method for class 'ddsimcares'
plotAcceptance(
obj,
ncomp = obj$ncomp.selected,
limType = "classic",
show = "auto",
log = FALSE,
show.legend = TRUE,
colors = c(regular = "#2679B2", extreme = "#F2B825", outlier = "#D22C2F", alien =
"#2679B2", external = "#D22C2F", unknown = "#3c6784", excluded = "#00ff00"),
lim.lty = c(2, 3),
lim.col = c("darkgray", "darkgray"),
lim.lwd = c(1, 1),
lab.cex = 0.75,
lab.col = "#808080",
ylim = NULL,
xlim = NULL,
res.name = NULL,
show.excluded = FALSE,
...
)
obj |
DD-SIMCA results (object of class |
ncomp |
number of components in the model to show the plot for. |
limType |
limit type to show the plot for ('classic' or 'robust') |
show |
name of subset to show ( |
log |
logical, apply log transformation or not. |
show.legend |
logica, show or not colorbar legend on the plot. |
colors |
named vector with colors for every role |
lim.lty |
vector with two values - types of the lines showing critical limits (extreme, outlier). |
lim.col |
vector with two values - colors of the lines showing critical limits (extreme, outlier). |
lim.lwd |
vector with two values - thickness of the lines showing critical limits (extreme, outlier). |
lab.cex |
font size for data point labels. |
lab.col |
color for data point labels. |
ylim |
limits for y-axis, if NULL will be estimated automatically. |
xlim |
limits for x-axis, if NULL will be estimated automatically. |
res.name |
optional, short name for the result object (shown in plot title). |
show.excluded |
logical, show or not the excluded rows (objects). |
... |
other parameters compatible with |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.