| plotAliens.ddsimcares | R Documentation |
Aliens plot for DD-SIMCA results.
## S3 method for class 'ddsimcares'
plotAliens(
obj,
ncomp = obj$ncomp.selected,
limType = "classic",
main = sprintf("Aliens (A = %d)", ncomp),
xlab = "Number of aliens (expected)",
ylab = "Number of aliens (observed)",
col = "#2679b2",
ellipse.col = "#eeeeee",
show.plot = TRUE,
...
)
obj |
DD-SIMCA results (object of class |
ncomp |
number of components in the model to show the plot for. |
limType |
limit type to show the plot for ('classic' or 'robust') |
main |
main title. |
xlab |
label for x-axis. |
ylab |
label for y-axis. |
col |
color of the plot points. |
ellipse.col |
color of the confidence ellipse elements. |
show.plot |
logical, if FALSE returns only values and does not show the plot. |
... |
other parameters compatible with |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.