| plotDistances.ddsimcares | R Documentation |
Show with distance values (score, orthogonal or full) vs object indices for DD-SIMCA results.
## S3 method for class 'ddsimcares'
plotDistances(
obj,
ncomp = obj$ncomp.selected,
limType = "classic",
distance = "h",
log = FALSE,
show.legend = TRUE,
lim.lty = c(2, 3),
lim.col = c("darkgray", "darkgray"),
lim.lwd = c(1, 1),
ylim = NULL,
xlim = NULL,
show.plot = TRUE,
show.excluded = FALSE,
...
)
obj |
DD-SIMCA results (object of class |
ncomp |
number of components to show the plot for. |
limType |
limit type to show the plot for ('classic' or 'robust') |
distance |
which distance to show ( |
log |
logical, apply log transformation or not. |
show.legend |
logica, show or not colorbar legend on the plot. |
lim.lty |
vector with two values - types of the lines showing critical limits (extreme, outlier). |
lim.col |
vector with two values - colors of the lines showing critical limits (extreme, outlier). |
lim.lwd |
vector with two values - thickness of the lines showing critical limits (extreme, outlier). |
ylim |
limits for y-axis, if NULL will be estimated automatically. |
xlim |
limits for x-axis, if NULL will be estimated automatically. |
show.plot |
logical, if FALSE returns only values and does not show the plot. |
show.excluded |
logical, show or not the excluded rows (objects). |
... |
other parameters compatible with |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.