| plotEigenvalues.pca | R Documentation |
Shows a plot with eigenvalues vs. number of components, optionally with log or sqrt transformation applied.
## S3 method for class 'pca'
plotEigenvalues(
obj,
type = "b",
labels = "values",
transform = "none",
xticks = seq_len(obj$ncomp),
ylab = NULL,
...
)
obj |
a PCA model (object of class |
type |
type of the plot ("l", "b", "h") |
labels |
what to show as labels for plot objects. |
transform |
transformation to apply to eigenvalues: "none", "log", or "sqrt" |
xticks |
vector with ticks for x-axis |
ylab |
label for y-axis |
... |
other plot parameters (see |
The eigenvalues represent the variance captured by each principal component. Transformations
can be useful for identifying the number of significant components: "log" applies
log(eigenvalues) and "sqrt" applies sqrt(eigenvalues).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.