| plotFoM.ddsimcares | R Documentation |
Figure of merit plot.
## S3 method for class 'ddsimcares'
plotFoM(
obj,
fom = "sens",
limType = "classic",
type = "b",
ylim = c(0, 1.1),
show.plot = TRUE,
...
)
obj |
DD-SIMCA results (object of class |
fom |
name of the figure of merit to show the plot for ('sens', 'spec', 'sel', 'eff', 'acc'). |
limType |
limit type to show the plot for ('classic' or 'robust'). |
type |
type of plot (can be 'b', 'l', or 'h'). |
ylim |
limits for y-axis. |
show.plot |
logical, if FALSE returns only values and does not show the plot. |
... |
any parameters for Shows the selected figure of merit values vs. number of components. Pay attention, that some of the FoMs may not be available, for example if result object is made only for members of the target class, only sensitivity ('sens') is available. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.