| plotSelection.ipls | R Documentation |
Shows PLS performance for each selected or excluded intervals at the first iteration.
## S3 method for class 'ipls'
plotSelection(
obj,
glob.ncomp = obj$gm$ncomp.selected,
main = "iPLS results",
xlab = obj$xaxis.name,
ylab = if (is.null(obj$cv)) "RMSEP" else "RMSECV",
xlim = NULL,
ylim = NULL,
...
)
obj |
iPLS results (object of class ipls). |
glob.ncomp |
number of components for global PLS model with all intervals. |
main |
main title for the plot. |
xlab |
label for x-axis. |
ylab |
label for y-axis. |
xlim |
limits for x-axis. |
ylim |
limits for y-axis. |
... |
other arguments. |
The plot shows intervals as bars, which height corresponds to RMSECV obtained when particular interval was selected (forward) or excluded (backward) from a model at the first iteration. The intervals found optimal after backward/forward iPLS selection are shown with green color while the other intervals are gray.
See examples in help for ipls function.
summary.ipls, plotRMSE.ipls
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.