| plotSensitivity.ddsimcares | R Documentation |
Sensitivity plot.
## S3 method for class 'ddsimcares'
plotSensitivity(
obj,
show.ci = FALSE,
ci.col = "#a0a0a0",
ci.lty = c(3, 2, 3),
...
)
obj |
DD-SIMCA results (object of class |
show.ci |
logical, show or not the expected sensitivity and 95% confidence interval for it. |
ci.col |
color for lines showing expected sensitivity and confidence interval. |
ci.lty |
type of lines (lower, expected, upper) for the expected sensitivity and confidence interval. |
... |
any parameters suitable for the |
The method is a wrapper for more general plotFoM.ddsimcares method with a
possibility to show confidence interval for the expected sensitivity.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.