| prep.emsc | R Documentation |
Applies Extended Multiplicative Scatter Correction to data rows
prep.emsc(data, degree = 0, mspectrum = NULL, lnorm = NULL, A = NULL)
data |
a matrix with data values. |
degree |
polynomial degree, if 0 then the result will be the same as for conventional MSC. |
mspectrum |
optional reference spectrum (if not provided, mean spectrum will be used). |
lnorm |
do not use, required for training of preprocessing model. |
A |
do not use, required for training of preprocessing model. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.