| prep.fit | R Documentation |
Fits preprocessing model
prep.fit(obj, x)
obj |
list with preprocessing methods (created using |
x |
matrix with training set to be used for computing data dependent parameters |
same list but with updated methods parameters computed based on the training set.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.