| prep.spikes | R Documentation |
Removes spikes from Raman spectra using median absolute deviation computed for signal differences. See [1] for more details
prep.spikes(data, width = 5, threshold = 6)
data |
a matrix with data values |
width |
width of the moving median filter |
threshold |
threshold to compare modified z-score value with to detect the spike. |
data matrix with processed values
1. Darren A. Whitaker, Kevin Hayes, A simple algorithm for despiking Raman spectra, Chemometrics and Intelligent Laboratory Systems, 179, 2018, pp. 82-84, 10.1016/j.chemolab.2018.06.009.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.