| preparePlotData | R Documentation |
The function checks that 'data' contains correct numeric values, checks for mandatory attributes (row and column names, x- and y-axis values and names, etc.) and adds them if necessary.
Another thing is to remove hidden columns and split the rest to visible and hidden values (if excluded rows are present).
preparePlotData(data)
data |
dataset (vector, matrix or data frame) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.