| processStrangers | R Documentation |
Computes classification outcomes for members of non-target classes.
processStrangers(res, indStrangers)
res |
a list with classification outcomes created by method |
indStrangers |
a vector with logical values pointing on data items corresponding to members of non-target classes. |
the res list where roles vector is filled for class members, values for TN and FP, as
well as statistics for computing Type II error and related things (beta, s, f0, hz, Mz, Sz, k, m).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.