| selratio | R Documentation |
Calculates selectivity ratio for all response variables in the PLS model with given number of components.
selratio(obj, ncomp = obj$ncomp.selected)
obj |
a PLS model (object of class |
ncomp |
number of components to use in the model for calculation. |
array nvar x ny with selectivity ratio values
[1] Tarja Rajalahti et al. Chemometrics and Laboratory Systems, 95 (2009), pp. 35-48.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.