| writeCSV | R Documentation |
Method to write outcomes of any result object to CSV file
writeCSV(res, fileName, name, sep = ",", dataFile = "", ...)
res |
result object ( |
fileName |
name (or full path) to CSV file to be created. |
name |
short name of the result object (e.g. |
sep |
values separator (either |
dataFile |
optional, name of the data file used to create the results. |
... |
other optional parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.