| writeCSV.ddsimcares | R Documentation |
Saves DD-SIMCA results to CSV file with structure identical to the one generated by web-application at https://mda.tools/ddsimca
## S3 method for class 'ddsimcares'
writeCSV(
res,
fileName,
name = "cal",
sep = ",",
dataFile = "",
ncomp = res$ncomp.selected,
limType = "classic",
src = "mdatools for R",
...
)
res |
DD-SIMCA results (object of class |
fileName |
name (or full path) to CSV file to be created. |
name |
short name of the result object (e.g. |
sep |
values separator (either |
dataFile |
optional, name of the data file used to create the results. |
ncomp |
model complexity (number of components) to compute the classiciation results for. |
limType |
limit type to use ('classic' or 'robust') |
src |
optional, source of the results |
... |
other optional parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.