| writeCSV.pcares | R Documentation |
Saves PCA results to CSV file with structure identical to the one generated by web-application at https://mda.tools/pca
## S3 method for class 'pcares'
writeCSV(
res,
fileName,
name,
sep = ",",
dataFile = "",
classes = NULL,
model = NULL,
...
)
res |
PCA results (object of class |
fileName |
name (or full path) to CSV file to be created. |
name |
short name of the result object (e.g. |
sep |
values separator (either |
dataFile |
optional, name of the data file used to create the results. |
classes |
vector with class names for every object in the dataset (if any) |
model |
optional, if PCA model is provided, loadings and vectors for centering/scaling will be added |
... |
other optional parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.