| writeCSV.plsres | R Documentation |
Saves PLS results to CSV file with structure identical to the one generated by web-application at https://mda.tools/pls
## S3 method for class 'plsres'
writeCSV(res, fileName, name, sep = ",", dataFile = "", ...)
res |
PLS results (object of class |
fileName |
name (or full path) to CSV file to be created. |
name |
short name of the result object (e.g. |
sep |
values separator (either |
dataFile |
optional, name of the data file used to create the results. |
... |
other optional parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.